Stan Math Library: stan/math/fwd/scal/fun/log1p.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log1p.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_LOG1P_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_LOG1P_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/log1p.hpp>
7 #include <stan/math/prim/scal/fun/constants.hpp>
8
9 namespace stan {
10
11 namespace math {
12
13 template <typename T>
14 inline
15 fvar<T>
16 log1p(const fvar<T>& x) {
17 using stan::math::log1p;
18 using stan::math::NOT_A_NUMBER;
19 if (x.val_ < -1.0)
20 return fvar<T>(NOT_A_NUMBER, NOT_A_NUMBER);
21 else
22 return fvar<T>(log1p(x.val_), x.d_ / (1 + x.val_));
23 }
24 }
25 }
26 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::NOT_A_NUMBER
const double NOT_A_NUMBER
(Quiet) not-a-number value.
Definition: constants.hpp:56
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
constants.hpp
stan::math::log1p
fvar< T > log1p(const fvar< T > &x)
Definition: log1p.hpp:16
log1p.hpp
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.